Package 'jameelinst.rpkg.theme'
| Title: |
A 'pkgdown' Template for Jameel Institute Packages |
| Description: |
Package website colours and logos taken from the Imperial
College London and Jameel Institute brand guidelines. |
| Authors: |
Pratik Gupte [aut, cre] (ORCID:
<https://orcid.org/0000-0001-5294-7819>),
Abdul Latif Jameel Institute for Disease and Emergency Analytics [cph,
fnd],
Imperial College of Science, Technology and Medicine [cph, fnd] |
| Maintainer: |
Pratik Gupte <[email protected]> |
| License: |
`use_mit_license()`, `use_gpl3_license()` or friends to pick a
license |
| Version: |
0.0.0.9000 |
| Built: |
2026-05-14 07:32:29 UTC |
| Source: |
https://github.com/jameel-institute/jameelinst.rpkg.theme |
Help Index